@@ -1,9 +1,13 @@
-import os
+"""
+Library for initializing AutoNode configs.
+"""
+
 import getpass
-import shutil
-import time
 import json
+import os
+import shutil
 import subprocess
+import time
 
 from pyhmy import (
     cli,
@@ -21,25 +25,24 @@ from .common import (
     node_config,
     save_node_config,
     b32_addr_len,
-    bls_key_len,
     bls_key_dir,
     imported_wallet_pass_file_dir,
     cli_bin_path,
     protect_file,
     save_protected_file,
-    user,
     harmony_dir,
     node_dir,
     node_sh_log_dir
 )
-from .util import (
-    input_with_print,
-    shard_for_bls
-)
 from .passphrase import (
     encrypt_wallet_passphrase,
     is_valid_passphrase
 )
+from .util import (
+    input_with_print,
+    shard_for_bls,
+    is_bls_file
+)
 
 
 def _import_validator_address():
@@ -95,15 +98,6 @@ def _display_warning(field_name):
     log(f'{Typgpy.WARNING}{field_name} can not be changed after creation!{Typgpy.ENDC}')
 
 
-def _bls_filter(file_name, suffix):
-    if file_name.startswith('.') or not file_name.endswith(suffix):
-        return False
-    tok = file_name.split(".")
-    if len(tok) != 2 or len(tok[0]) != bls_key_len:
-        return False
-    return True
-
-
 def _wallet_pass_filter(file_name):
     if not file_name.startswith('one1') or not file_name.endswith(".pass"):
         return False
@@ -128,8 +122,8 @@ def _import_bls_passphrase():
     NOTE: .pass files are SUBJECT TO CHANGE as they are files used
     by node.sh & CLI layer of the harmony program.
     """
-    bls_keys = list(filter(lambda e: _bls_filter(e, '.key'), os.listdir(bls_key_dir)))
-    bls_pass = list(filter(lambda e: _bls_filter(e, '.pass'), os.listdir(bls_key_dir)))
+    bls_keys = list(filter(lambda e: is_bls_file(e, '.key'), os.listdir(bls_key_dir)))
+    bls_pass = list(filter(lambda e: is_bls_file(e, '.pass'), os.listdir(bls_key_dir)))
     imported_bls_keys, imported_bls_pass = set(), set()
     for k in bls_keys:
         imported_bls_keys.add(k.split('.')[0])
@@ -160,7 +154,7 @@ def _import_bls(passphrase):
 
     Assumes that imported BLS key files and passphrase have been validated.
     """
-    bls_keys = list(filter(lambda e: _bls_filter(e, '.key'), os.listdir(bls_key_dir)))
+    bls_keys = list(filter(lambda e: is_bls_file(e, '.key'), os.listdir(bls_key_dir)))
     if passphrase is None:  # Assumes passphrase files were imported when passphrase is None.
         if node_config['shard'] is not None:
             log(f"{Typgpy.WARNING}[!] Shard option ignored since BLS keys were imported.{Typgpy.ENDC}")
@@ -195,7 +189,8 @@ def _import_bls(passphrase):
     elif node_config['shard'] is not None:
         assert isinstance(node_config['shard'], int), f"shard: {node_config['shard']} is not an integer."
         while True:
-            key = json_load(cli.single_call(['hmy', 'keys', 'generate-bls-key', '--passphrase-file', tmp_bls_pass_path]))
+            key = json_load(
+                cli.single_call(['hmy', 'keys', 'generate-bls-key', '--passphrase-file', tmp_bls_pass_path]))
             public_bls_key, bls_file_path = key['public-key'], key['encrypted-private-key-path']
             shard_id = json_load(cli.single_call(['hmy', '--node', f'{node_config["endpoint"]}', 'utility',
                                                   'shard-for-bls', public_bls_key]))['shard-id']
